---
Summary: Customize columns in sbl by multiple views in config and meta
Status: Done
---

# Description

In config, allow a 'columns' fields which has, ordered, the columns that will appear in `sbl`.

Allow a `--columns=`/`-c` with a comma separated list that will override the columns field in the config.

# Cucumber

**GIVEN** a configuration file with a `columns` field
**WHEN** `sbl` is run
**THEN** the columns are shown

**GIVEN** a `columns` param with comma separated fields
**WHEN** `sbl` is run
**THEN** the columns are shown

# Implementation note

No unit test exists for this yet.
